==> mybody_api_client-0.4.1.tar.gz: mybody_api_client-0.4.1/mybody_api_client/routes/admin/accounts/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes
from .services import AdminAccountServiceRoute
from .roles import AdminAccountRolesRoute


class AdminAccountRoute(BaseRoute):
    prefix = '/accounts'

    services = AdminAccountServiceRoute()
    roles = AdminAccountRolesRoute()

    async def get(self, id_: int = None):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/get',
            parameters={
                'id': id_,
            },
            response_key='accounts',
        )

    async def search(self, id_: int = None, username: str = None, page: int = None):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/search',
            parameters={
                'id': id_,
                'username': username,
                'page': page,
            },
        )

==> mybody_api_client-0.4.3.tar.gz: mybody_api_client-0.4.3/mybody_api_client/routes/admin/accounts/__init__.py <==
#
# (c) 2024, Yegor Yakubovich, yegoryakubovich.com, personal@yegoryakybovich.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from mybody_api_client.utils import BaseRoute, RequestTypes
from .services import AdminAccountServiceRoute
from .roles import AdminAccountRolesRoute


class AdminAccountRoute(BaseRoute):
    prefix = '/accounts'

    services = AdminAccountServiceRoute()
    roles = AdminAccountRolesRoute()

    async def get(self, id_: int = None):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/get',
            parameters={
                'id': id_,
            },
            response_key='account',
        )

    async def search(self, id_: int = None, username: str = None, page: int = None):
        return await self.request(
            type_=RequestTypes.POST,
            prefix='/search',
            parameters={
                'id': id_,
                'username': username,
                'page': page,
            },
        )
